@@ -29,5 +29,4 @@ class Tor(BaseProvider):
                 continue
             item = {"range": address, "comment": "tor exit node"}
             out_ranges.append(item)
-        output = {"header_comments": header_comments, "ranges": out_ranges}
-        return output
+        return {"header_comments": header_comments, "ranges": out_ranges}
